diff --git a/composer.lock b/composer.lock
index 036646d92564495e23288ecbfc3a6589b8d9e90c..16796f6ef41f1d80836e53cf9bd76ae38aa47473 100644
--- a/composer.lock
+++ b/composer.lock
@@ -137,16 +137,16 @@
         },
         {
             "name": "ocramius/proxy-manager",
-            "version": "0.5.1",
+            "version": "0.5.2",
             "source": {
                 "type": "git",
                 "url": "https://github.com/Ocramius/ProxyManager.git",
-                "reference": "eaaf10f9a24ffd79a3e388809f6d61f229e261bd"
+                "reference": "0ac0eb3e8e04c7fa75caaf1a43c5405623abf8f5"
             },
             "dist": {
                 "type": "zip",
-                "url": "https://api.github.com/repos/Ocramius/ProxyManager/zipball/eaaf10f9a24ffd79a3e388809f6d61f229e261bd",
-                "reference": "eaaf10f9a24ffd79a3e388809f6d61f229e261bd",
+                "url": "https://api.github.com/repos/Ocramius/ProxyManager/zipball/0ac0eb3e8e04c7fa75caaf1a43c5405623abf8f5",
+                "reference": "0ac0eb3e8e04c7fa75caaf1a43c5405623abf8f5",
                 "shasum": ""
             },
             "require": {
@@ -155,7 +155,7 @@
             },
             "require-dev": {
                 "ext-phar": "*",
-                "phpunit/phpunit": "~3.7",
+                "phpunit/phpunit": "~4.0",
                 "squizlabs/php_codesniffer": "1.5.*"
             },
             "suggest": {
@@ -184,8 +184,7 @@
                 {
                     "name": "Marco Pivetta",
                     "email": "ocramius@gmail.com",
-                    "homepage": "http://ocramius.github.com/",
-                    "role": "Developer"
+                    "homepage": "http://ocramius.github.com/"
                 }
             ],
             "description": "A library providing utilities to generate, instantiate and generally operate with Object Proxies",
@@ -197,7 +196,7 @@
                 "proxy pattern",
                 "service proxies"
             ],
-            "time": "2014-03-12 14:00:19"
+            "time": "2014-09-28 14:18:11"
         },
         {
             "name": "oyejorge/less.php",
@@ -513,17 +512,17 @@
         },
         {
             "name": "symfony/yaml",
-            "version": "v2.5.4",
+            "version": "v2.5.5",
             "target-dir": "Symfony/Component/Yaml",
             "source": {
                 "type": "git",
                 "url": "https://github.com/symfony/Yaml.git",
-                "reference": "01a7695bcfb013d0a15c6757e15aae120342986f"
+                "reference": "b1dbc53593b98c2d694ebf383660ac9134d30b96"
             },
             "dist": {
                 "type": "zip",
-                "url": "https://api.github.com/repos/symfony/Yaml/zipball/01a7695bcfb013d0a15c6757e15aae120342986f",
-                "reference": "01a7695bcfb013d0a15c6757e15aae120342986f",
+                "url": "https://api.github.com/repos/symfony/Yaml/zipball/b1dbc53593b98c2d694ebf383660ac9134d30b96",
+                "reference": "b1dbc53593b98c2d694ebf383660ac9134d30b96",
                 "shasum": ""
             },
             "require": {
@@ -556,7 +555,7 @@
             ],
             "description": "Symfony Yaml Component",
             "homepage": "http://symfony.com",
-            "time": "2014-08-31 03:22:04"
+            "time": "2014-09-22 09:14:18"
         },
         {
             "name": "zendframework/zendframework",
diff --git a/vendor/autoload.php b/vendor/autoload.php
index fda071db9125ebde330dbb7ebea3eea127b68b78..3d383ebdaa81994b58f62ac9db2921a8f50b372b 100644
--- a/vendor/autoload.php
+++ b/vendor/autoload.php
@@ -4,4 +4,4 @@
 
 require_once __DIR__ . '/composer' . '/autoload_real.php';
 
-return ComposerAutoloaderInit787a7480744b64d80a4758b706585039::getLoader();
+return ComposerAutoloaderInit0f2072e16558438728ae5fe1a74a0c86::getLoader();
diff --git a/vendor/composer/autoload_real.php b/vendor/composer/autoload_real.php
index 731556ae4993f7c502a1495946d54a038ee1f906..ea9f2bfdc7163281f9dc8ab210930463c9677e98 100644
--- a/vendor/composer/autoload_real.php
+++ b/vendor/composer/autoload_real.php
@@ -2,7 +2,7 @@
 
 // autoload_real.php @generated by Composer
 
-class ComposerAutoloaderInit787a7480744b64d80a4758b706585039
+class ComposerAutoloaderInit0f2072e16558438728ae5fe1a74a0c86
 {
     private static $loader;
 
@@ -19,9 +19,9 @@ class ComposerAutoloaderInit787a7480744b64d80a4758b706585039
             return self::$loader;
         }
 
-        spl_autoload_register(array('ComposerAutoloaderInit787a7480744b64d80a4758b706585039', 'loadClassLoader'), true, true);
+        spl_autoload_register(array('ComposerAutoloaderInit0f2072e16558438728ae5fe1a74a0c86', 'loadClassLoader'), true, true);
         self::$loader = $loader = new \Composer\Autoload\ClassLoader();
-        spl_autoload_unregister(array('ComposerAutoloaderInit787a7480744b64d80a4758b706585039', 'loadClassLoader'));
+        spl_autoload_unregister(array('ComposerAutoloaderInit0f2072e16558438728ae5fe1a74a0c86', 'loadClassLoader'));
 
         $includePaths = require __DIR__ . '/include_paths.php';
         array_push($includePaths, get_include_path());
@@ -48,7 +48,7 @@ class ComposerAutoloaderInit787a7480744b64d80a4758b706585039
     }
 }
 
-function composerRequire787a7480744b64d80a4758b706585039($file)
+function composerRequire0f2072e16558438728ae5fe1a74a0c86($file)
 {
     require $file;
 }
diff --git a/vendor/composer/installed.json b/vendor/composer/installed.json
index a8547aea4425908e9f9c179cd5d18141eced6bce..f75eae69138f0deecd5f9857010245f3e972822c 100644
--- a/vendor/composer/installed.json
+++ b/vendor/composer/installed.json
@@ -468,55 +468,6 @@
         ],
         "description": "Package containes ISPN (International Standard Product Numbers) validations such as:\n * ISSN\n * ISBN\n * ISMN\n * ISRC (International Standard Recording Code)\n * EAN8\n * EAN13\n * EAN14\n * UCC12\n * SSCC"
     },
-    {
-        "name": "symfony/yaml",
-        "version": "v2.5.4",
-        "version_normalized": "2.5.4.0",
-        "target-dir": "Symfony/Component/Yaml",
-        "source": {
-            "type": "git",
-            "url": "https://github.com/symfony/Yaml.git",
-            "reference": "01a7695bcfb013d0a15c6757e15aae120342986f"
-        },
-        "dist": {
-            "type": "zip",
-            "url": "https://api.github.com/repos/symfony/Yaml/zipball/01a7695bcfb013d0a15c6757e15aae120342986f",
-            "reference": "01a7695bcfb013d0a15c6757e15aae120342986f",
-            "shasum": ""
-        },
-        "require": {
-            "php": ">=5.3.3"
-        },
-        "time": "2014-08-31 03:22:04",
-        "type": "library",
-        "extra": {
-            "branch-alias": {
-                "dev-master": "2.5-dev"
-            }
-        },
-        "installation-source": "dist",
-        "autoload": {
-            "psr-0": {
-                "Symfony\\Component\\Yaml\\": ""
-            }
-        },
-        "notification-url": "https://packagist.org/downloads/",
-        "license": [
-            "MIT"
-        ],
-        "authors": [
-            {
-                "name": "Symfony Community",
-                "homepage": "http://symfony.com/contributors"
-            },
-            {
-                "name": "Fabien Potencier",
-                "email": "fabien@symfony.com"
-            }
-        ],
-        "description": "Symfony Yaml Component",
-        "homepage": "http://symfony.com"
-    },
     {
         "name": "zendframework/zendxml",
         "version": "1.0.0",
@@ -841,17 +792,17 @@
     },
     {
         "name": "ocramius/proxy-manager",
-        "version": "0.5.1",
-        "version_normalized": "0.5.1.0",
+        "version": "0.5.2",
+        "version_normalized": "0.5.2.0",
         "source": {
             "type": "git",
             "url": "https://github.com/Ocramius/ProxyManager.git",
-            "reference": "eaaf10f9a24ffd79a3e388809f6d61f229e261bd"
+            "reference": "0ac0eb3e8e04c7fa75caaf1a43c5405623abf8f5"
         },
         "dist": {
             "type": "zip",
-            "url": "https://api.github.com/repos/Ocramius/ProxyManager/zipball/eaaf10f9a24ffd79a3e388809f6d61f229e261bd",
-            "reference": "eaaf10f9a24ffd79a3e388809f6d61f229e261bd",
+            "url": "https://api.github.com/repos/Ocramius/ProxyManager/zipball/0ac0eb3e8e04c7fa75caaf1a43c5405623abf8f5",
+            "reference": "0ac0eb3e8e04c7fa75caaf1a43c5405623abf8f5",
             "shasum": ""
         },
         "require": {
@@ -860,7 +811,7 @@
         },
         "require-dev": {
             "ext-phar": "*",
-            "phpunit/phpunit": "~3.7",
+            "phpunit/phpunit": "~4.0",
             "squizlabs/php_codesniffer": "1.5.*"
         },
         "suggest": {
@@ -870,7 +821,7 @@
             "zendframework/zend-stdlib": "To use the hydrator proxy",
             "zendframework/zend-xmlrpc": "To have the XmlRpc adapter (Remote Object feature)"
         },
-        "time": "2014-03-12 14:00:19",
+        "time": "2014-09-28 14:18:11",
         "type": "library",
         "extra": {
             "branch-alias": {
@@ -891,8 +842,7 @@
             {
                 "name": "Marco Pivetta",
                 "email": "ocramius@gmail.com",
-                "homepage": "http://ocramius.github.com/",
-                "role": "Developer"
+                "homepage": "http://ocramius.github.com/"
             }
         ],
         "description": "A library providing utilities to generate, instantiate and generally operate with Object Proxies",
@@ -904,5 +854,54 @@
             "proxy pattern",
             "service proxies"
         ]
+    },
+    {
+        "name": "symfony/yaml",
+        "version": "v2.5.5",
+        "version_normalized": "2.5.5.0",
+        "target-dir": "Symfony/Component/Yaml",
+        "source": {
+            "type": "git",
+            "url": "https://github.com/symfony/Yaml.git",
+            "reference": "b1dbc53593b98c2d694ebf383660ac9134d30b96"
+        },
+        "dist": {
+            "type": "zip",
+            "url": "https://api.github.com/repos/symfony/Yaml/zipball/b1dbc53593b98c2d694ebf383660ac9134d30b96",
+            "reference": "b1dbc53593b98c2d694ebf383660ac9134d30b96",
+            "shasum": ""
+        },
+        "require": {
+            "php": ">=5.3.3"
+        },
+        "time": "2014-09-22 09:14:18",
+        "type": "library",
+        "extra": {
+            "branch-alias": {
+                "dev-master": "2.5-dev"
+            }
+        },
+        "installation-source": "dist",
+        "autoload": {
+            "psr-0": {
+                "Symfony\\Component\\Yaml\\": ""
+            }
+        },
+        "notification-url": "https://packagist.org/downloads/",
+        "license": [
+            "MIT"
+        ],
+        "authors": [
+            {
+                "name": "Symfony Community",
+                "homepage": "http://symfony.com/contributors"
+            },
+            {
+                "name": "Fabien Potencier",
+                "email": "fabien@symfony.com"
+            }
+        ],
+        "description": "Symfony Yaml Component",
+        "homepage": "http://symfony.com"
     }
 ]
diff --git a/vendor/ocramius/proxy-manager/.scrutinizer-ci.phpunit.xml.dist b/vendor/ocramius/proxy-manager/.scrutinizer-ci.phpunit.xml.dist
new file mode 100644
index 0000000000000000000000000000000000000000..7a55711925cf80f70c99612632342b43ea288667
--- /dev/null
+++ b/vendor/ocramius/proxy-manager/.scrutinizer-ci.phpunit.xml.dist
@@ -0,0 +1,28 @@
+<?xml version="1.0"?>
+<phpunit
+    bootstrap="./tests/Bootstrap.php"
+    colors="true"
+    convertErrorsToExceptions="true"
+    convertNoticesToExceptions="true"
+    convertWarningsToExceptions="true"
+    verbose="true"
+    stopOnFailure="false"
+    processIsolation="false"
+    backupGlobals="false"
+    syntaxCheck="true"
+>
+    <testsuite name="ProxyManager tests">
+        <directory>./tests/ProxyManagerTest</directory>
+    </testsuite>
+    <groups>
+        <exclude>
+            <group>Functional</group>
+            <group>Performance</group>
+        </exclude>
+    </groups>
+    <filter>
+        <whitelist addUncoveredFilesFromWhitelist="true">
+            <directory suffix=".php">./src</directory>
+        </whitelist>
+    </filter>
+</phpunit>
diff --git a/vendor/ocramius/proxy-manager/.scrutinizer.yml b/vendor/ocramius/proxy-manager/.scrutinizer.yml
index df6d207ec6428e3e20941e7443dc089d72ddc6fa..717d725bc8fc96531cdd11a34549195593d0b912 100644
--- a/vendor/ocramius/proxy-manager/.scrutinizer.yml
+++ b/vendor/ocramius/proxy-manager/.scrutinizer.yml
@@ -2,9 +2,11 @@ before_commands:
     - "composer install --no-dev --prefer-source"
 
 tools:
+    external_code_coverage:
+        timeout: 600
     php_code_coverage:
         enabled: true
-        test_command: phpunit -c phpunit.xml.dist --exclude-group Functional,Performance
+        test_command: phpunit -c .scrutinizer-ci.phpunit.xml.dist
     php_code_sniffer:
         enabled: true
         config:
diff --git a/vendor/ocramius/proxy-manager/.travis.install.sh b/vendor/ocramius/proxy-manager/.travis.install.sh
new file mode 100644
index 0000000000000000000000000000000000000000..373c5efcbf78952d345771389094dcba7ff1fc41
--- /dev/null
+++ b/vendor/ocramius/proxy-manager/.travis.install.sh
@@ -0,0 +1,11 @@
+set -x
+if [ "$TRAVIS_PHP_VERSION" = 'hhvm' ] || [ "$TRAVIS_PHP_VERSION" = 'hhvm-nightly' ] ; then
+    curl -sS https://getcomposer.org/installer > composer-installer.php
+    hhvm composer-installer.php
+    hhvm -v ResourceLimit.SocketDefaultTimeout=30 -v Http.SlowQueryThreshold=30000 composer.phar update --prefer-source
+    hhvm -v ResourceLimit.SocketDefaultTimeout=30 -v Http.SlowQueryThreshold=30000 composer.phar install --dev --prefer-source
+else
+    composer self-update
+    composer update --prefer-source
+    composer install --dev --prefer-source
+fi
diff --git a/vendor/ocramius/proxy-manager/.travis.yml b/vendor/ocramius/proxy-manager/.travis.yml
index bfb3ba3eee98c487c03112691aab910c3b9fbf32..2191faaf1c504235c755852aa7ea73328adbe38d 100644
--- a/vendor/ocramius/proxy-manager/.travis.yml
+++ b/vendor/ocramius/proxy-manager/.travis.yml
@@ -7,17 +7,21 @@ php:
   - 5.5
   - 5.6
   - hhvm
+  - hhvm-nightly
 
 before_script:
-  - composer self-update
-  - composer update --prefer-source; composer install --dev --prefer-source;
+  - sh .travis.install.sh
 
 script:
   - ./vendor/bin/phpunit --coverage-clover ./build/logs/clover.xml --exclude-group Performance
-  - ./vendor/bin/phpunit ./tests/language-feature-scripts/
   - php -n ./vendor/bin/phpunit --group=Performance
   - ./vendor/bin/phpcs --standard=PSR2 ./src/ ./tests/
 
 matrix:
   allow_failures:
     - php: hhvm
+    - php: hhvm-nightly
+
+after_script:
+  - wget https://scrutinizer-ci.com/ocular.phar
+  - php ocular.phar code-coverage:upload --format=php-clover ./build/logs/clover.xml
diff --git a/vendor/ocramius/proxy-manager/LICENSE b/vendor/ocramius/proxy-manager/LICENSE
index 49adae035a2c355b285322fe8a3b4c2474621503..d7f722397b6a878a16b964065d476b3052dcc9eb 100644
--- a/vendor/ocramius/proxy-manager/LICENSE
+++ b/vendor/ocramius/proxy-manager/LICENSE
@@ -16,4 +16,4 @@ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
\ No newline at end of file
+SOFTWARE.
diff --git a/vendor/ocramius/proxy-manager/README.md b/vendor/ocramius/proxy-manager/README.md
index 4244f597cd821a1472f38da95eb78a888419b2d3..c4848795c02e995a6fe58ec5a024b67bf387b19f 100644
--- a/vendor/ocramius/proxy-manager/README.md
+++ b/vendor/ocramius/proxy-manager/README.md
@@ -9,6 +9,8 @@ This library aims at providing abstraction for generating various kinds of [prox
 [![Scrutinizer Quality Score](https://scrutinizer-ci.com/g/Ocramius/ProxyManager/badges/quality-score.png?s=eaa858f876137ed281141b1d1e98acfa739729ed)](https://scrutinizer-ci.com/g/Ocramius/ProxyManager/)
 [![SensioLabsInsight](https://insight.sensiolabs.com/projects/69fe5f97-b1c8-4ddd-93ce-900b8b788cf2/mini.png)](https://insight.sensiolabs.com/projects/69fe5f97-b1c8-4ddd-93ce-900b8b788cf2)
 [![Dependency Status](https://www.versioneye.com/package/php--ocramius--proxy-manager/badge.png)](https://www.versioneye.com/package/php--ocramius--proxy-manager)
+[![Reference Status](https://www.versioneye.com/php/ocramius:proxy-manager/reference_badge.svg)](https://www.versioneye.com/php/ocramius:proxy-manager/references)
+[![HHVM Status](http://hhvm.h4cc.de/badge/ocramius/proxy-manager.png)](http://hhvm.h4cc.de/package/ocramius/proxy-manager)
 
 [![Total Downloads](https://poser.pugx.org/ocramius/proxy-manager/downloads.png)](https://packagist.org/packages/ocramius/proxy-manager)
 [![Latest Stable Version](https://poser.pugx.org/ocramius/proxy-manager/v/stable.png)](https://packagist.org/packages/ocramius/proxy-manager)
@@ -95,7 +97,7 @@ A Null Object Proxy can be created from an object, a class name or an interface
 ```php
 $factory = new \ProxyManager\Factory\NullObjectFactory();
 
-$proxy = $factory->createProxy('My\EntityObjectInterface'); // created from interface name
+$proxy = $factory->createProxy('My\EntityObjectInterface');
 $proxy->getName(); // empty return
 
 $proxy = $factory->createProxy($entity); // created from object
@@ -142,17 +144,6 @@ $proxy->doFoo();
 See the [complete documentation about lazy loading ghost objects](/docs/lazy-loading-ghost-object.md)
 in the `docs/` directory.
 
-## Lazy References
-
-A lazy reference proxy is actually a proxy backed by some kind of reference holder (usually a registry) that can fetch
-existing instances of a particular object.
-
-A lazy reference is usually necessary when multiple instances of the same object can be avoided, or when the instances
-are not hard links (like with [Weakref](http://php.net/manual/en/book.weakref.php)), and could be garbage-collected to
-save memory in long time running processes.
-
-This feature [yet to be planned](https://github.com/Ocramius/ProxyManager/issues/8).
-
 ## Remote Object
 
 A remote object proxy is an object that is located on a different system, but is used as if it was available locally.
diff --git a/vendor/ocramius/proxy-manager/composer.json b/vendor/ocramius/proxy-manager/composer.json
index fa7e22638d4a624614afd7f9b9b93bddb8bbcc06..cde5eca13c8a7aad61faa711fdb25f3b76c0d24c 100644
--- a/vendor/ocramius/proxy-manager/composer.json
+++ b/vendor/ocramius/proxy-manager/composer.json
@@ -4,7 +4,6 @@
     "type":              "library",
     "license":           "MIT",
     "homepage":          "https://github.com/Ocramius/ProxyManager",
-    "minimum-stability": "dev",
     "keywords":          [
         "proxy",
         "proxy pattern",
@@ -25,7 +24,7 @@
     },
     "require-dev": {
         "ext-phar":                    "*",
-        "phpunit/phpunit":             "~3.7",
+        "phpunit/phpunit":             "~4.0",
         "squizlabs/php_codesniffer":   "1.5.*"
     },
     "suggest": {
@@ -40,6 +39,12 @@
             "ProxyManager\\": "src"
         }
     },
+    "autoload-dev": {
+        "psr-0": {
+            "ProxyManagerTest\\": "tests",
+            "ProxyManagerTestAsset\\": "tests"
+        }
+    },
     "extra": {
         "branch-alias": {
             "dev-master": "0.6.x-dev"
diff --git a/vendor/ocramius/proxy-manager/docs/lazy-loading-ghost-object.md b/vendor/ocramius/proxy-manager/docs/lazy-loading-ghost-object.md
index 4c93439a06e471092c9f3639dede2a98a3b3e813..15ae42662bf986e6903e02fab3a61fe6891cce17 100644
--- a/vendor/ocramius/proxy-manager/docs/lazy-loading-ghost-object.md
+++ b/vendor/ocramius/proxy-manager/docs/lazy-loading-ghost-object.md
@@ -189,7 +189,7 @@ unset($proxy->someProperty);
 clone $proxy;
 
 // serializing the proxy
-$unserialized = serialize(unserialize($proxy));
+$unserialized = unserialize(serialize($proxy));
 ```
 
 Remember to call `$proxy->setProxyInitializer(null);` to disable initialization of your proxy, or it will happen more
diff --git a/vendor/ocramius/proxy-manager/phpdox.xml.dist b/vendor/ocramius/proxy-manager/phpdox.xml.dist
index c610db976ac8410df19205df29395fc9c38783a5..6cbf78ba1811fce9b1ad3166bb513b16615560a0 100644
--- a/vendor/ocramius/proxy-manager/phpdox.xml.dist
+++ b/vendor/ocramius/proxy-manager/phpdox.xml.dist
@@ -13,4 +13,4 @@
             <build engine="html" enabled="true" output="api"/>
         </generator>
     </project>
-</phpdox>
\ No newline at end of file
+</phpdox>
diff --git a/vendor/ocramius/proxy-manager/phpmd.xml.dist b/vendor/ocramius/proxy-manager/phpmd.xml.dist
index 4a9f7df5bfe83850f26a112450f1b68408ea7b0b..ae91e86a1585bc3b62116edc12ed3659f9cf2409 100644
--- a/vendor/ocramius/proxy-manager/phpmd.xml.dist
+++ b/vendor/ocramius/proxy-manager/phpmd.xml.dist
@@ -13,4 +13,4 @@
         <exclude name="EvalExpression"/>
     </rule>
     <rule ref="rulesets/naming.xml"/>
-</ruleset>
\ No newline at end of file
+</ruleset>
diff --git a/vendor/ocramius/proxy-manager/phpunit.xml.dist b/vendor/ocramius/proxy-manager/phpunit.xml.dist
index 94f3665c6c5221e8142108bb6e3d3dedfd3b6a61..b595427c2607ae56a5ca3a5853d63e94c38f1a17 100644
--- a/vendor/ocramius/proxy-manager/phpunit.xml.dist
+++ b/vendor/ocramius/proxy-manager/phpunit.xml.dist
@@ -1,6 +1,6 @@
 <?xml version="1.0"?>
 <phpunit
-    bootstrap="./tests/Bootstrap.php"
+    bootstrap="./vendor/autoload.php"
     colors="true"
     convertErrorsToExceptions="true"
     convertNoticesToExceptions="true"
@@ -14,6 +14,9 @@
     <testsuite name="ProxyManager tests">
         <directory>./tests/ProxyManagerTest</directory>
     </testsuite>
+    <testsuite name="ProxyManager language integration tests">
+        <directory suffix=".phpt">./tests/language-feature-scripts</directory>
+    </testsuite>
     <filter>
         <whitelist addUncoveredFilesFromWhitelist="true">
             <directory suffix=".php">./src</directory>
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/Configuration.php b/vendor/ocramius/proxy-manager/src/ProxyManager/Configuration.php
index 486ff5dd83a058352740ac0d30e45157c28093d1..77ff28c481053715e3381e6a07e987b586dcb20a 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/Configuration.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/Configuration.php
@@ -63,6 +63,7 @@ class Configuration
 
     /**
      * @deprecated deprecated since version 0.5
+     * @codeCoverageIgnore
      */
     public function setAutoGenerateProxies()
     {
@@ -72,6 +73,7 @@ class Configuration
      * @return bool
      *
      * @deprecated deprecated since version 0.5
+     * @codeCoverageIgnore
      */
     public function doesAutoGenerateProxies()
     {
@@ -126,7 +128,7 @@ class Configuration
     }
 
     /**
-     * @return null|string
+     * @return string
      */
     public function getProxiesTargetDir()
     {
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/FileLocator/FileLocatorInterface.php b/vendor/ocramius/proxy-manager/src/ProxyManager/FileLocator/FileLocatorInterface.php
index 2980c5d2e6e65faf1e47f9ade8352efab2b344ef..c52ac0281ae59951eb7b0238e872a53e6fdadc26 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/FileLocator/FileLocatorInterface.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/FileLocator/FileLocatorInterface.php
@@ -29,9 +29,9 @@ interface FileLocatorInterface
     /**
      * Retrieves the file name for the given proxy
      *
-     * @param $className
+     * @param string $className
      *
-     * @return mixed
+     * @return string
      */
     public function getProxyFileName($className);
 }
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/Generator/MagicMethodGenerator.php b/vendor/ocramius/proxy-manager/src/ProxyManager/Generator/MagicMethodGenerator.php
index e0bd1f863a1dfb112b34606246b4de1ef8d901f8..462aa8f8ed5274d2a895d22b0a8117e38aad9034 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/Generator/MagicMethodGenerator.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/Generator/MagicMethodGenerator.php
@@ -28,6 +28,11 @@ use ReflectionClass;
  */
 class MagicMethodGenerator extends MethodGenerator
 {
+    /**
+     * @param ReflectionClass $originalClass
+     * @param string          $name
+     * @param array           $parameters
+     */
     public function __construct(ReflectionClass $originalClass, $name, array $parameters = array())
     {
         parent::__construct(
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/Generator/ParameterGenerator.php b/vendor/ocramius/proxy-manager/src/ProxyManager/Generator/ParameterGenerator.php
index 49b9764b923f2e6d411dc096141aa8f3847895a6..7960d42d10d79efcd3873f6a3b2a4ceff79dc475 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/Generator/ParameterGenerator.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/Generator/ParameterGenerator.php
@@ -101,15 +101,13 @@ class ParameterGenerator extends ZendParameterGenerator
             return '';
         }
 
-        if (is_string($this->defaultValue)) {
-            return ' = ' . ValueGenerator::escape($this->defaultValue);
-        }
+        $defaultValue = $this->defaultValue instanceof ValueGenerator
+            ? $this->defaultValue
+            : new ValueGenerator($this->defaultValue);
 
-        if ($this->defaultValue instanceof ValueGenerator) {
-            $this->defaultValue->setOutputMode(ValueGenerator::OUTPUT_SINGLE_LINE);
-        }
+        $defaultValue->setOutputMode(ValueGenerator::OUTPUT_SINGLE_LINE);
 
-        return ' = ' . $this->defaultValue;
+        return ' = ' . $defaultValue;
     }
 
     /**
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/Inflector/ClassNameInflectorInterface.php b/vendor/ocramius/proxy-manager/src/ProxyManager/Inflector/ClassNameInflectorInterface.php
index db46a78f7ff998a725bcb5536ef93dbc31166416..71fc43275bb640c326fa8069ec18fe9d5784fa6a 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/Inflector/ClassNameInflectorInterface.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/Inflector/ClassNameInflectorInterface.php
@@ -46,7 +46,7 @@ interface ClassNameInflectorInterface
      * @param string $className
      * @param array  $options   arbitrary options to be used for the generated class name
      *
-     * @return mixed
+     * @return string
      */
     public function getProxyClassName($className, array $options = array());
 
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/AccessInterceptorScopeLocalizer/MethodGenerator/Constructor.php b/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/AccessInterceptorScopeLocalizer/MethodGenerator/Constructor.php
index 37b196843c9c8aa412efa178e65f004e5ea6e965..3770a16f3eafe3e9ed0575aefc74993e065764de 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/AccessInterceptorScopeLocalizer/MethodGenerator/Constructor.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/AccessInterceptorScopeLocalizer/MethodGenerator/Constructor.php
@@ -59,7 +59,7 @@ class Constructor extends MethodGenerator
         $localizedProperties = array();
 
         foreach ($originalClass->getProperties() as $originalProperty) {
-            if ((PHP_VERSION_ID < 50400 || (defined('HHVM_VERSION'))) && $originalProperty->isPrivate()) {
+            if ((! method_exists('Closure', 'bind')) && $originalProperty->isPrivate()) {
                 // @codeCoverageIgnoreStart
                 throw UnsupportedProxiedClassException::unsupportedLocalizedReflectionProperty($originalProperty);
                 // @codeCoverageIgnoreEnd
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/LazyLoadingGhost/MethodGenerator/CallInitializer.php b/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/LazyLoadingGhost/MethodGenerator/CallInitializer.php
index 92be722e725c443bfc31170d41b82a16920e66f8..36f2794fdf1cc1062da196f7b291ddcad99ea816 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/LazyLoadingGhost/MethodGenerator/CallInitializer.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/LazyLoadingGhost/MethodGenerator/CallInitializer.php
@@ -37,8 +37,8 @@ class CallInitializer extends MethodGenerator
      */
     public function __construct(
         PropertyGenerator $initializerProperty,
-        PropertyGenerator $publicPropertiesDefaults,
-        PropertyGenerator $initializationTracker
+        PropertyGenerator $publicPropsDefaults,
+        PropertyGenerator $initTracker
     ) {
         parent::__construct(UniqueIdentifierGenerator::getIdentifier('callInitializer'));
         $this->setDocblock("Triggers initialization logic for this ghost object");
@@ -51,12 +51,12 @@ class CallInitializer extends MethodGenerator
         $this->setVisibility(static::VISIBILITY_PRIVATE);
 
         $initializer    = $initializerProperty->getName();
-        $initialization = $initializationTracker->getName();
+        $initialization = $initTracker->getName();
 
         $this->setBody(
             'if ($this->' . $initialization . ' || ! $this->' . $initializer . ') {' . "\n    return;\n}\n\n"
             . "\$this->" . $initialization . " = true;\n\n"
-            . "foreach (self::\$" . $publicPropertiesDefaults->getName() . " as \$key => \$default) {\n"
+            . "foreach (self::\$" . $publicPropsDefaults->getName() . " as \$key => \$default) {\n"
             . "    \$this->\$key = \$default;\n"
             . "}\n\n"
             . '$this->' . $initializer . '->__invoke'
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/LazyLoadingGhostGenerator.php b/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/LazyLoadingGhostGenerator.php
index 7a2b4e10e1cd1ec76c4c6c6ab4c87e3c9407e726..b8e7ffa9a908957d4707beb50c5cf5bf448a3cdb 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/LazyLoadingGhostGenerator.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/LazyLoadingGhostGenerator.php
@@ -58,9 +58,9 @@ class LazyLoadingGhostGenerator implements ProxyGeneratorInterface
      */
     public function generate(ReflectionClass $originalClass, ClassGenerator $classGenerator)
     {
-        $interfaces               = array('ProxyManager\\Proxy\\GhostObjectInterface');
-        $publicProperties         = new PublicPropertiesMap($originalClass);
-        $publicPropertiesDefaults = new PublicPropertiesDefaults($originalClass);
+        $interfaces          = array('ProxyManager\\Proxy\\GhostObjectInterface');
+        $publicProperties    = new PublicPropertiesMap($originalClass);
+        $publicPropsDefaults = new PublicPropertiesDefaults($originalClass);
 
         if ($originalClass->isInterface()) {
             $interfaces[] = $originalClass->getName();
@@ -72,9 +72,9 @@ class LazyLoadingGhostGenerator implements ProxyGeneratorInterface
         $classGenerator->addPropertyFromGenerator($initializer = new InitializerProperty());
         $classGenerator->addPropertyFromGenerator($initializationTracker = new InitializationTracker());
         $classGenerator->addPropertyFromGenerator($publicProperties);
-        $classGenerator->addPropertyFromGenerator($publicPropertiesDefaults);
+        $classGenerator->addPropertyFromGenerator($publicPropsDefaults);
 
-        $init = new CallInitializer($initializer, $publicPropertiesDefaults, $initializationTracker);
+        $init = new CallInitializer($initializer, $publicPropsDefaults, $initializationTracker);
 
         $classGenerator->addMethodFromGenerator($init);
 
diff --git a/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/Util/PublicScopeSimulator.php b/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/Util/PublicScopeSimulator.php
index 5a823e980d02e5c6aa116daebb5321c5024a12bc..a908e58bcd3d8f52d56e1ff0fd1648097a663730 100644
--- a/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/Util/PublicScopeSimulator.php
+++ b/vendor/ocramius/proxy-manager/src/ProxyManager/ProxyGenerator/Util/PublicScopeSimulator.php
@@ -170,13 +170,13 @@ class PublicScopeSimulator
     }
 
     /**
-     * Generates code to bind operations to the parent scope if supported by the current PHP version
+     * Generates code to bind operations to the parent scope if supported by the current PHP implementation
      *
      * @return string
      */
     private static function getScopeReBind()
     {
-        if (PHP_VERSION_ID < 50400 || defined('HHVM_VERSION')) {
+        if (! method_exists('Closure', 'bind')) {
             // @codeCoverageIgnoreStart
             return '';
             // @codeCoverageIgnoreEnd
diff --git a/vendor/ocramius/proxy-manager/tests/Bootstrap.php b/vendor/ocramius/proxy-manager/tests/Bootstrap.php
deleted file mode 100644
index 9f84dcd692c8bba4052de9a9e26dc7220a1c6466..0000000000000000000000000000000000000000
--- a/vendor/ocramius/proxy-manager/tests/Bootstrap.php
+++ /dev/null
@@ -1,39 +0,0 @@
-<?php
-/*
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * This software consists of voluntary contributions made by many individuals
- * and is licensed under the MIT license.
- */
-
-ini_set('error_reporting', E_ALL | E_STRICT);
-
-$files = array(__DIR__ . '/../vendor/autoload.php', __DIR__ . '/../../../autoload.php');
-
-foreach ($files as $file) {
-    if (file_exists($file)) {
-        $loader = require $file;
-
-        break;
-    }
-}
-
-if (! isset($loader)) {
-    throw new RuntimeException('vendor/autoload.php could not be found. Did you run `php composer.phar install`?');
-}
-
-/* @var $loader \Composer\Autoload\ClassLoader */
-$loader->add('ProxyManagerTest\\', __DIR__);
-$loader->add('ProxyManagerTestAsset\\', __DIR__);
-
-unset($files, $file, $loader);
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/AccessInterceptorScopeLocalizerFunctionalTest.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/AccessInterceptorScopeLocalizerFunctionalTest.php
index bedb96097cf30352595365ec2c76361ca487fc2e..5db91f4ab57fe4e0800c616c41a0d64e24abc0a6 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/AccessInterceptorScopeLocalizerFunctionalTest.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/AccessInterceptorScopeLocalizerFunctionalTest.php
@@ -47,7 +47,7 @@ class AccessInterceptorScopeLocalizerFunctionalTest extends PHPUnit_Framework_Te
      */
     public static function setUpBeforeClass()
     {
-        if (PHP_VERSION_ID < 50400 || defined('HHVM_VERSION')) {
+        if (! method_exists('Closure', 'bind')) {
             throw new PHPUnit_Framework_SkippedTestError(
                 'PHP 5.3 doesn\'t support scope localization of private properties'
             );
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/LazyLoadingValueHolderFunctionalTest.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/LazyLoadingValueHolderFunctionalTest.php
index 6dc1d3b30021e07f37f7acc96f11516a115c2f83..166dd0257fb2c83d31198dc184181aa5ccecff86 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/LazyLoadingValueHolderFunctionalTest.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/LazyLoadingValueHolderFunctionalTest.php
@@ -213,6 +213,29 @@ class LazyLoadingValueHolderFunctionalTest extends PHPUnit_Framework_TestCase
         $this->assertSame('foo', $proxy->property0);
     }
 
+    /**
+     * @group 16
+     *
+     * Verifies that initialization of a value holder proxy may happen multiple times
+     */
+    public function testWillAllowMultipleProxyInitialization()
+    {
+        $proxyClass  = $this->generateProxy('ProxyManagerTestAsset\\BaseClass');
+        $counter     = 0;
+        $initializer = function (& $wrappedInstance) use (& $counter) {
+            $wrappedInstance = new BaseClass();
+
+            $wrappedInstance->publicProperty = (string) ($counter += 1);
+        };
+
+        /* @var $proxy BaseClass */
+        $proxy = new $proxyClass($initializer);
+
+        $this->assertSame('1', $proxy->publicProperty);
+        $this->assertSame('2', $proxy->publicProperty);
+        $this->assertSame('3', $proxy->publicProperty);
+    }
+
     /**
      * Generates a proxy for the given class name, and retrieves its class name
      *
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/MultipleProxyGenerationTest.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/MultipleProxyGenerationTest.php
index 4686293d43419c11b3810c6fddd254bcaa38fe9b..de3bfee1c06d7a1d06b38c861db8c2a91fa4d211 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/MultipleProxyGenerationTest.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Functional/MultipleProxyGenerationTest.php
@@ -58,9 +58,7 @@ class MultipleProxyGenerationTest extends PHPUnit_Framework_TestCase
 
         $reflectionClass = new ReflectionClass($className);
 
-        if ((defined('HHVM_VERSION') || PHP_VERSION_ID < 50400)
-            && $reflectionClass->getProperties(ReflectionProperty::IS_PRIVATE)
-        ) {
+        if ((! method_exists('Closure', 'bind')) && $reflectionClass->getProperties(ReflectionProperty::IS_PRIVATE)) {
             $skipScopeLocalizerTests = true;
         }
 
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Generator/MethodGeneratorTest.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Generator/MethodGeneratorTest.php
index 6a6c8307e98994eb8f77e09a03b7f73817ddf66e..cd0a5248a243d53bc29252a50671e81630d6537d 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Generator/MethodGeneratorTest.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Generator/MethodGeneratorTest.php
@@ -75,4 +75,22 @@ class MethodGeneratorTest extends PHPUnit_Framework_TestCase
 
         $this->assertSame(MethodGenerator::VISIBILITY_PRIVATE, $method->getVisibility());
     }
+
+    public function testGeneratedParametersFromReflection()
+    {
+        $method = MethodGenerator::fromReflection(new MethodReflection(
+            'ProxyManagerTestAsset\\BaseClass',
+            'publicTypeHintedMethod'
+        ));
+
+        $this->assertSame('publicTypeHintedMethod', $method->getName());
+
+        $parameters = $method->getParameters();
+
+        $this->assertCount(1, $parameters);
+
+        $param = $parameters['param'];
+
+        $this->assertSame('stdClass', $param->getType());
+    }
 }
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Generator/ParameterGeneratorTest.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Generator/ParameterGeneratorTest.php
index f9874084810c29c599ec0088dabac466936490c4..98ac8b5c912f008d6c1aa11cf2f4d9234446182a 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Generator/ParameterGeneratorTest.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/Generator/ParameterGeneratorTest.php
@@ -124,6 +124,22 @@ class ParameterGeneratorTest extends PHPUnit_Framework_TestCase
             1
         ));
 
-        $this->assertNull($parameter->getDefaultValue()->getValue());
+        $this->assertSame('null', strtolower((string) $parameter->getDefaultValue()));
+    }
+
+    public function testGeneratedParametersAreProperlyEscaped()
+    {
+        $parameter = new ParameterGenerator();
+
+        $parameter->setName('foo');
+        $parameter->setDefaultValue('\'bar\\baz');
+
+        $this->assertThat(
+            $parameter->generate(),
+            $this->logicalOr(
+                $this->equalTo('$foo = \'\\\'bar\\baz\''),
+                $this->equalTo('$foo = \'\\\'bar\\\\baz\'')
+            )
+        );
     }
 }
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/ProxyGenerator/AccessInterceptorScopeLocalizer/MethodGenerator/ConstructorTest.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/ProxyGenerator/AccessInterceptorScopeLocalizer/MethodGenerator/ConstructorTest.php
index 9202412a65f4f5d033844db812ab7a6d3a6fe461..f9a3758e506b93172f37d32ec6c493a06898e512 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/ProxyGenerator/AccessInterceptorScopeLocalizer/MethodGenerator/ConstructorTest.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/ProxyGenerator/AccessInterceptorScopeLocalizer/MethodGenerator/ConstructorTest.php
@@ -146,7 +146,7 @@ $this->post = $suffixInterceptors;',
      */
     public function testBodyStructureWithPrivateProperties()
     {
-        if (PHP_VERSION_ID < 50400 || defined('HHVM_VERSION')) {
+        if (! method_exists('Closure', 'bind')) {
             $this->setExpectedException('ProxyManager\Exception\UnsupportedProxiedClassException');
         }
 
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/ProxyGenerator/AccessInterceptorScopeLocalizerTest.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/ProxyGenerator/AccessInterceptorScopeLocalizerTest.php
index f90decc8e303f1fee2fb745f7026e7f9c49cbbdf..4aa1d6035acd396a508f5807a8c2e87510c6fe7a 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/ProxyGenerator/AccessInterceptorScopeLocalizerTest.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTest/ProxyGenerator/AccessInterceptorScopeLocalizerTest.php
@@ -48,7 +48,7 @@ class AccessInterceptorScopeLocalizerTest extends AbstractProxyGeneratorTest
             return parent::testGeneratesValidCode($className);
         }
 
-        if ((PHP_VERSION_ID < 50400 || defined('HHVM_VERSION'))
+        if ((! method_exists('Closure', 'bind'))
             && $reflectionClass->getProperties(ReflectionProperty::IS_PRIVATE)
         ) {
             $this->setExpectedException('ProxyManager\Exception\UnsupportedProxiedClassException');
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTestAsset/BaseInterface.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTestAsset/BaseInterface.php
index 8749a8df7ef31b177f7c00d401f88fc7ef0a1134..27aeda5c7e5c69ff4d62e222dbe09fa925b681ef 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTestAsset/BaseInterface.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTestAsset/BaseInterface.php
@@ -27,7 +27,7 @@ namespace ProxyManagerTestAsset;
 interface BaseInterface
 {
     /**
-     * @return mixed
+     * @return string
      */
     public function publicMethod();
 }
diff --git a/vendor/ocramius/proxy-manager/tests/ProxyManagerTestAsset/RemoteProxy/FooServiceInterface.php b/vendor/ocramius/proxy-manager/tests/ProxyManagerTestAsset/RemoteProxy/FooServiceInterface.php
index 4894b213899599ed2a9311ec67dd8770858464e0..af0b764b8c8c104a6e16f791a6943d2c0cb17640 100644
--- a/vendor/ocramius/proxy-manager/tests/ProxyManagerTestAsset/RemoteProxy/FooServiceInterface.php
+++ b/vendor/ocramius/proxy-manager/tests/ProxyManagerTestAsset/RemoteProxy/FooServiceInterface.php
@@ -27,7 +27,7 @@ namespace ProxyManagerTestAsset\RemoteProxy;
 interface FooServiceInterface
 {
     /**
-     * @return mixed
+     * @return string
      */
     public function foo();
 }
diff --git a/vendor/ocramius/proxy-manager/tests/TestConfiguration.php.dist b/vendor/ocramius/proxy-manager/tests/TestConfiguration.php.dist
deleted file mode 100644
index 3d0507eb7550a039eb68d3153b13bae5102c9e1e..0000000000000000000000000000000000000000
--- a/vendor/ocramius/proxy-manager/tests/TestConfiguration.php.dist
+++ /dev/null
@@ -1,19 +0,0 @@
-<?php
-/*
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
- * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
- * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
- * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
- * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
- * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
- * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
- *
- * This software consists of voluntary contributions made by many individuals
- * and is licensed under the MIT license.
- */
-
-return array();
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-read.phpt
index 313312a1ca16a9c9eb887082cc0394c53e892660..0dff2c7c8b38b3814c11d887b95f604ee378d899 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-read.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 $proxy->sweets;
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-unset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-unset.phpt
index 3f32a2484495fc630d6706498e269077618ce1c9..e6e6eeb69af9515323bde7d302699285d2088920 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-unset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-unset.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 unset($proxy->sweets);
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-write.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-write.phpt
index b108ac2b7ea62465949a161b8f46e1da4d6a3dba..e87d520af95303e7e052621315b7b481e1deb7bd 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-write.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-private-property-write.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 $proxy->sweets = 'stolen';
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access %s property%S in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-read.phpt
index 8d47a63cae71eb75d18ca47d019ba899ee21ed0b..ed579f5d7cdc72cd7b41b96cd753683ece234be5 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-read.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 $proxy->sweets;
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-unset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-unset.phpt
index 21ed252688dd3dfce48741c6f91cfd6b0869a51c..d8fcd495010c7e86738c70aea016947bc660f96d 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-unset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-unset.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 unset($proxy->sweets);
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property%sin %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-write.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-write.phpt
index 31acfafa2cf7381d5221cf7dd42408ddebb79607..f288b0b4f7ad801f15d1dd5e88b3693126a6e6af 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-write.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-denies-protected-property-write.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 $proxy->sweets = 'stolen';
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property%sin %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-isset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-isset.phpt
index 4b7b916acafa8ed4dfef242e1f8c5a0eedb8ac19..d9eef6795d51cb6d61c7c0a5e0580b07c8e5f401 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-isset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-isset.phpt
@@ -2,7 +2,7 @@
 Verifies that generated access interceptors disallow private property direct isset check
 --SKIPIF--
 <?php
-if (PHP_VERSION_ID < 50400) {
+if (! method_exists('Closure', 'bind')) {
     echo 'skip PHP 5.4+ is needed to localize private properties';
 }
 ?>
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-read.phpt
index 436b76b92fc5498c5fba8f8517edc64e3fdec4d9..18a6c95f9babafaccdf1680361019c11287be536 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-read.phpt
@@ -2,7 +2,7 @@
 Verifies that generated access interceptors disallow private property direct read
 --SKIPIF--
 <?php
-if (PHP_VERSION_ID < 50400) {
+if (! method_exists('Closure', 'bind')) {
     echo 'skip PHP 5.4+ is needed to localize private properties';
 }
 ?>
@@ -23,4 +23,4 @@ $proxy = $factory->createProxy(new Kitchen());
 $proxy->sweets;
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
+%SFatal error: Cannot access private property %s::$sweets in %s on line %d
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-unset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-unset.phpt
index c296ef4f26a0826e5a462a116414212550fcbc84..92a64e2d77fa7856b39e3ecc9838d353120576bb 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-unset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-unset.phpt
@@ -2,7 +2,7 @@
 Verifies that generated access interceptors disallow private property direct unset
 --SKIPIF--
 <?php
-if (PHP_VERSION_ID < 50400) {
+if (! method_exists('Closure', 'bind')) {
     echo 'skip PHP 5.4+ is needed to localize private properties';
 }
 ?>
@@ -23,4 +23,4 @@ $proxy = $factory->createProxy(new Kitchen());
 unset($proxy->sweets);
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
+%SFatal error: Cannot %s property%sin %s on line %d
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-write.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-write.phpt
index bd8e115d7eb8346d653ae0ffc5517fb4d779dc63..a0b3cc1f591cb8fd93ea47c6f50e218b9dcd4368 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-write.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-private-property-write.phpt
@@ -2,7 +2,7 @@
 Verifies that generated access interceptors disallow private property direct write
 --SKIPIF--
 <?php
-if (PHP_VERSION_ID < 50400) {
+if (! method_exists('Closure', 'bind')) {
     echo 'skip PHP 5.4+ is needed to localize private properties';
 }
 ?>
@@ -23,4 +23,4 @@ $proxy = $factory->createProxy(new Kitchen());
 $proxy->sweets = 'stolen';
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
+%SFatal error: Cannot %s property%sin %s on line %d
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-read.phpt
index d3519a4290502b70e36ec4a6134b23630e7e94a7..c97b09165e9c78b4e7b9e29813d6a012e25d91da 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-read.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 $proxy->sweets;
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
+%SFatal error: Cannot access protected property %s::$sweets in %s on line %d
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-unset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-unset.phpt
index cb20b6d595ca3a39fb57eb93f1963bcbe151673a..91cc4f9423879e54e16ebe8ffec2ec213fd33332 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-unset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-unset.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 unset($proxy->sweets);
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
+%SFatal error: Cannot %s property%sin %s on line %d
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-write.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-write.phpt
index b4ab7bdd9db978039b2060ab5856a941e26f8c69..97da7390162bef880d5ce0341fb1ab1d78fc8c74 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-write.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/access-interceptor-scope-localizer-denies-protected-property-write.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy(new Kitchen());
 $proxy->sweets = 'stolen';
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
+%SFatal error: Cannot %s property%sin %s on line %d
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/init.php b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/init.php
index cab41588326b717dd3a79c9860fc988fc6935e75..ce6cffc92f584a601d9f79e189a3d1498defd797 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/init.php
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/init.php
@@ -3,7 +3,7 @@
 use ProxyManager\Configuration;
 use ProxyManager\GeneratorStrategy\EvaluatingGeneratorStrategy;
 
-require_once __DIR__ . '/../Bootstrap.php';
+require_once __DIR__ . '/../../vendor/autoload.php';
 
 $configuration = new Configuration();
 
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-inexisting-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-inexisting-property-read.phpt
index 73042abe09278dc4282ee8b5aaca7e059265be01..0b0267b30f0ec86e9f9bb765a8f4bcd827de8536 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-inexisting-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-inexisting-property-read.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy('Kitchen', function () {});
 $proxy->nonExisting;
 ?>
 --EXPECTF--
-Notice: Undefined property: Kitchen::$nonExisting in %s on line %d
\ No newline at end of file
+%SNotice: Undefined property: Kitchen::$nonExisting in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-read.phpt
index e1fd83bd3ff42efdd500bc07ed315c55cfbfb7fe..cdb0d09e07932beaa08e994ff4b2603e8648df79 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-read.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy('Kitchen', function () {});
 $proxy->sweets;
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-unset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-unset.phpt
index 62b1bf1e67c5218448a9bd14c3778fd1c3f95533..18580aaa1837352a33b6fa93adaaf1725c0ebf20 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-unset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-unset.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy('Kitchen', function () {});
 unset($proxy->sweets);
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-write.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-write.phpt
index e0840d73d37cf746f178fd40d26e174723d67e84..a081d71418fafe44b8e09970b5c1cce6fec25eff 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-write.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-private-property-write.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy('Kitchen', function () {});
 $proxy->sweets = 'stolen';
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access %s property%S in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-read.phpt
index 14633704e15fce95137807959138461a83cb3430..e71bb30281b14f9065f092789158f038d6139514 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-read.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy('Kitchen', function () {});
 $proxy->sweets;
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-unset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-unset.phpt
index a0a6643c6a7992f7239b1c0dd17bc35f3682c3c9..6e742a1bbdbf3f7043f5e46a5093170d7d31c2db 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-unset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-unset.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy('Kitchen', function () {});
 unset($proxy->sweets);
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property%sin %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-write.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-write.phpt
index 46f81785d2a1d89a69f75c2698ff41f5a89ade01..580f5a59c3e1fc3207169ba00bd3caf3f4dee20b 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-write.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-ghost-denies-protected-property-write.phpt
@@ -17,4 +17,4 @@ $proxy = $factory->createProxy('Kitchen', function () {});
 $proxy->sweets = 'stolen';
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property%sin %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-read.phpt
index 4660624b4e78502591816a9a622b280122dddb40..7631ec931701c128e9f02507db4e7551695abc25 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-read.phpt
@@ -20,4 +20,4 @@ $proxy = $factory->createProxy('Kitchen', function (& $wrapped, $proxy, $method,
 $proxy->sweets;
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-unset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-unset.phpt
index 443785fae237047b945b6790c39a05bd248112a6..1454f78c9846f562f0b1c68ff3b66084fa5189f9 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-unset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-unset.phpt
@@ -20,4 +20,4 @@ $proxy = $factory->createProxy('Kitchen', function (& $wrapped, $proxy, $method,
 unset($proxy->sweets);
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-write.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-write.phpt
index ad035ee83e22da16e72244f89484a96e47a8ec53..6b90e2f6712d1fbee4ff08fe9c2799345b81846c 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-write.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-private-property-write.phpt
@@ -20,4 +20,4 @@ $proxy = $factory->createProxy('Kitchen', function (& $wrapped, $proxy, $method,
 $proxy->sweets = 'stolen';
 ?>
 --EXPECTF--
-Fatal error: Cannot access private property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access %s property %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-read.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-read.phpt
index cfd2690dcbd0618af0128128af66cf07af627871..6f2df1d788f6f21d1305cae98f7c01f69798dd4b 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-read.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-read.phpt
@@ -20,4 +20,4 @@ $proxy = $factory->createProxy('Kitchen', function (& $wrapped, $proxy, $method,
 $proxy->sweets;
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-unset.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-unset.phpt
index 1fac6bb56a9401e65fe0e90b9c02391945636474..238a50fb7ca0aaee6daddedf34ebb2131068c7b6 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-unset.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-unset.phpt
@@ -20,4 +20,4 @@ $proxy = $factory->createProxy('Kitchen', function (& $wrapped, $proxy, $method,
 unset($proxy->sweets);
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property%sin %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-write.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-write.phpt
index bb89a31e6825a9236cb573dbe4cfd55dbce66835..f8c2cacd41e69e9420f102affb9d4d8485976734 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-write.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-denies-protected-property-write.phpt
@@ -20,4 +20,4 @@ $proxy = $factory->createProxy('Kitchen', function (& $wrapped, $proxy, $method,
 $proxy->sweets = 'stolen';
 ?>
 --EXPECTF--
-Fatal error: Cannot access protected property %s::$sweets in %s on line %d
\ No newline at end of file
+%SFatal error: Cannot %s property%sin %s on line %d
\ No newline at end of file
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-internal-php-classes.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-internal-php-classes.phpt
index 7aed1d1b217e1af95d29f53c9597383fd1e894c5..2a5a77707ae480e3be51263f37bf4515209d3b0d 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-internal-php-classes.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/lazy-loading-value-holder-internal-php-classes.phpt
@@ -11,9 +11,9 @@ class PharMock extends Phar
     {
     }
 
-    public function compress($message)
+    public function compress($compression_type, $file_ext = null)
     {
-        echo $message;
+        echo $compression_type;
     }
 }
 
diff --git a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/remote-object-json-adapter-denies-unknow-method.phpt b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/remote-object-json-adapter-denies-unknow-method.phpt
index fc0cb9f7060815372dd5002fcbf549cd77e4a093..1910a341c4f4779e308ac0f4ec927d0f0a93b6cb 100644
--- a/vendor/ocramius/proxy-manager/tests/language-feature-scripts/remote-object-json-adapter-denies-unknow-method.phpt
+++ b/vendor/ocramius/proxy-manager/tests/language-feature-scripts/remote-object-json-adapter-denies-unknow-method.phpt
@@ -40,4 +40,4 @@ var_dump($proxy->unknown());
 --EXPECTF--
 string(3) "baz"
 
-Fatal error: Call to undefined method %s::unknown() in %s on line %d
+%SFatal error: Call to undefined method %s::unknown%S in %s on line %d
diff --git a/vendor/symfony/yaml/Symfony/Component/Yaml/Escaper.php b/vendor/symfony/yaml/Symfony/Component/Yaml/Escaper.php
index 4a6b62161329c76730836da5095efe96ba6e786f..7f6ec2bef297d300bf533b79eaba5f1b6ed3cebe 100644
--- a/vendor/symfony/yaml/Symfony/Component/Yaml/Escaper.php
+++ b/vendor/symfony/yaml/Symfony/Component/Yaml/Escaper.php
@@ -26,18 +26,18 @@ class Escaper
     // first to ensure proper escaping because str_replace operates iteratively
     // on the input arrays. This ordering of the characters avoids the use of strtr,
     // which performs more slowly.
-    private static $escapees = array('\\\\', '\\"', '"',
+    private static $escapees = array('\\', '\\\\', '\\"', '"',
                                      "\x00",  "\x01",  "\x02",  "\x03",  "\x04",  "\x05",  "\x06",  "\x07",
                                      "\x08",  "\x09",  "\x0a",  "\x0b",  "\x0c",  "\x0d",  "\x0e",  "\x0f",
                                      "\x10",  "\x11",  "\x12",  "\x13",  "\x14",  "\x15",  "\x16",  "\x17",
                                      "\x18",  "\x19",  "\x1a",  "\x1b",  "\x1c",  "\x1d",  "\x1e",  "\x1f",
-                                     "\xc2\x85", "\xc2\xa0", "\xe2\x80\xa8", "\xe2\x80\xa9");
-    private static $escaped  = array('\\"', '\\\\', '\\"',
+                                     "\xc2\x85", "\xc2\xa0", "\xe2\x80\xa8", "\xe2\x80\xa9",);
+    private static $escaped  = array('\\\\', '\\"', '\\\\', '\\"',
                                      "\\0",   "\\x01", "\\x02", "\\x03", "\\x04", "\\x05", "\\x06", "\\a",
                                      "\\b",   "\\t",   "\\n",   "\\v",   "\\f",   "\\r",   "\\x0e", "\\x0f",
                                      "\\x10", "\\x11", "\\x12", "\\x13", "\\x14", "\\x15", "\\x16", "\\x17",
                                      "\\x18", "\\x19", "\\x1a", "\\e",   "\\x1c", "\\x1d", "\\x1e", "\\x1f",
-                                     "\\N", "\\_", "\\L", "\\P");
+                                     "\\N", "\\_", "\\L", "\\P",);
 
     /**
      * Determines if a PHP value would require double quoting in YAML.
diff --git a/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/DumperTest.php b/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/DumperTest.php
index ec2c65e3d06833e08f4ac3cfe80d43f443be95d7..51e12d41f545843de87ec9bf0a7292480b009001 100644
--- a/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/DumperTest.php
+++ b/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/DumperTest.php
@@ -55,7 +55,7 @@ class DumperTest extends \PHPUnit_Framework_TestCase
     {
         $this->dumper->setIndentation(7);
 
-$expected = <<<EOF
+        $expected = <<<EOF
 '': bar
 foo: '#bar'
 'foo''bar': {  }
@@ -108,10 +108,10 @@ EOF;
         $expected = <<<EOF
 { '': bar, foo: '#bar', 'foo''bar': {  }, bar: [1, foo], foobar: { foo: bar, bar: [1, foo], foobar: { foo: bar, bar: [1, foo] } } }
 EOF;
-$this->assertEquals($expected, $this->dumper->dump($this->array, -10), '->dump() takes an inline level argument');
-$this->assertEquals($expected, $this->dumper->dump($this->array, 0), '->dump() takes an inline level argument');
+        $this->assertEquals($expected, $this->dumper->dump($this->array, -10), '->dump() takes an inline level argument');
+        $this->assertEquals($expected, $this->dumper->dump($this->array, 0), '->dump() takes an inline level argument');
 
-$expected = <<<EOF
+        $expected = <<<EOF
 '': bar
 foo: '#bar'
 'foo''bar': {  }
@@ -199,6 +199,37 @@ EOF;
     {
         $this->dumper->dump(array('foo' => new A(), 'bar' => 1), 0, 0, true, false);
     }
+
+    /**
+     * @dataProvider getEscapeSequences
+     */
+    public function testEscapedEscapeSequencesInQuotedScalar($input, $expected)
+    {
+        $this->assertEquals($expected, $this->dumper->dump($input));
+    }
+
+    public function getEscapeSequences()
+    {
+        return array(
+            'null' => array("\t\\0", '"\t\\\\0"'),
+            'bell' => array("\t\\a", '"\t\\\\a"'),
+            'backspace' => array("\t\\b", '"\t\\\\b"'),
+            'horizontal-tab' => array("\t\\t", '"\t\\\\t"'),
+            'line-feed' => array("\t\\n", '"\t\\\\n"'),
+            'vertical-tab' => array("\t\\v", '"\t\\\\v"'),
+            'form-feed' => array("\t\\f", '"\t\\\\f"'),
+            'carriage-return' => array("\t\\r", '"\t\\\\r"'),
+            'escape' => array("\t\\e", '"\t\\\\e"'),
+            'space' => array("\t\\ ", '"\t\\\\ "'),
+            'double-quote' => array("\t\\\"", '"\t\\\\\\""'),
+            'slash' => array("\t\\/", '"\t\\\\/"'),
+            'backslash' => array("\t\\\\", '"\t\\\\\\\\"'),
+            'next-line' => array("\t\\N", '"\t\\\\N"'),
+            'non-breaking-space' => array("\t\\�", '"\t\\\\�"'),
+            'line-separator' => array("\t\\L", '"\t\\\\L"'),
+            'paragraph-separator' => array("\t\\P", '"\t\\\\P"'),
+        );
+    }
 }
 
 class A
diff --git a/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/Fixtures/YtsBasicTests.yml b/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/Fixtures/YtsBasicTests.yml
index ac0efa88d1a1bb7d510c54338a37e4905df68c4a..dfd93021d18cee7d51b8fc1f0c551e2712c1b63a 100644
--- a/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/Fixtures/YtsBasicTests.yml
+++ b/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/Fixtures/YtsBasicTests.yml
@@ -11,6 +11,30 @@ yaml: |
 php: |
     array('apple', 'banana', 'carrot')
 ---
+test: Sequence With Item Being Null In The Middle
+brief: |
+    You can specify a list in YAML by placing each
+    member of the list on a new line with an opening
+    dash. These lists are called sequences.
+yaml: |
+    - apple
+    -
+    - carrot
+php: |
+    array('apple', null, 'carrot')
+---
+test: Sequence With Last Item Being Null
+brief: |
+    You can specify a list in YAML by placing each
+    member of the list on a new line with an opening
+    dash. These lists are called sequences.
+yaml: |
+    - apple
+    - banana
+    -
+php: |
+    array('apple', 'banana', null)
+---
 test: Nested Sequences
 brief: |
     You can include a sequence within another
diff --git a/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/InlineTest.php b/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/InlineTest.php
index affe4f9c23e8389d09469a2fef5f94637121e4b7..96afb6bb2256f1ff57b7c19b7fc74452540b6b1c 100644
--- a/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/InlineTest.php
+++ b/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/InlineTest.php
@@ -147,6 +147,24 @@ class InlineTest extends \PHPUnit_Framework_TestCase
         $this->assertSame(array($foo), Inline::parse('[*foo]', false, false, array('foo' => $foo)));
     }
 
+    /**
+     * @expectedException \Symfony\Component\Yaml\Exception\ParseException
+     * @expectedExceptionMessage A reference must contain at least one character.
+     */
+    public function testParseUnquotedAsterisk()
+    {
+        Inline::parse('{ foo: * }');
+    }
+
+    /**
+     * @expectedException \Symfony\Component\Yaml\Exception\ParseException
+     * @expectedExceptionMessage A reference must contain at least one character.
+     */
+    public function testParseUnquotedAsteriskFollowedByAComment()
+    {
+        Inline::parse('{ foo: * #foo }');
+    }
+
     protected function getTestsForParse()
     {
         return array(
@@ -210,7 +228,7 @@ class InlineTest extends \PHPUnit_Framework_TestCase
             '[foo, {bar: foo, foo: [foo, {bar: foo}]}, [foo, {bar: foo}]]' => array('foo', array('bar' => 'foo', 'foo' => array('foo', array('bar' => 'foo'))), array('foo', array('bar' => 'foo'))),
 
             '[foo, bar: { foo: bar }]' => array('foo', '1' => array('bar' => array('foo' => 'bar'))),
-            '[foo, \'@foo.baz\', { \'%foo%\': \'foo is %foo%\', bar: \'%foo%\' }, true, \'@service_container\']' => array('foo', '@foo.baz', array('%foo%' => 'foo is %foo%', 'bar' => '%foo%',), true, '@service_container',),
+            '[foo, \'@foo.baz\', { \'%foo%\': \'foo is %foo%\', bar: \'%foo%\' }, true, \'@service_container\']' => array('foo', '@foo.baz', array('%foo%' => 'foo is %foo%', 'bar' => '%foo%'), true, '@service_container'),
         );
     }
 
@@ -257,7 +275,7 @@ class InlineTest extends \PHPUnit_Framework_TestCase
 
             '[foo, { bar: foo, foo: [foo, { bar: foo }] }, [foo, { bar: foo }]]' => array('foo', array('bar' => 'foo', 'foo' => array('foo', array('bar' => 'foo'))), array('foo', array('bar' => 'foo'))),
 
-            '[foo, \'@foo.baz\', { \'%foo%\': \'foo is %foo%\', bar: \'%foo%\' }, true, \'@service_container\']' => array('foo', '@foo.baz', array('%foo%' => 'foo is %foo%', 'bar' => '%foo%',), true, '@service_container',),
+            '[foo, \'@foo.baz\', { \'%foo%\': \'foo is %foo%\', bar: \'%foo%\' }, true, \'@service_container\']' => array('foo', '@foo.baz', array('%foo%' => 'foo is %foo%', 'bar' => '%foo%'), true, '@service_container'),
         );
     }
 }
diff --git a/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/ParserTest.php b/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/ParserTest.php
index 9480a21f95a5dd08967b44735ef95814d06d3314..da248d7dec0dfd33252c8e858983df520f1dcc32 100644
--- a/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/ParserTest.php
+++ b/vendor/symfony/yaml/Symfony/Component/Yaml/Tests/ParserTest.php
@@ -405,7 +405,7 @@ foo: |-
 
 EOF;
         $expected = array(
-            'foo' => "\n\nbar"
+            'foo' => "\n\nbar",
         );
 
         $this->assertSame($expected, $this->parser->parse($yaml));
@@ -449,7 +449,7 @@ EOF;
         $yamls = array(
             iconv("UTF-8", "ISO-8859-1", "foo: 'äöüß'"),
             iconv("UTF-8", "ISO-8859-15", "euro: '€'"),
-            iconv("UTF-8", "CP1252", "cp1252: '©ÉÇáñ'")
+            iconv("UTF-8", "CP1252", "cp1252: '©ÉÇáñ'"),
         );
 
         foreach ($yamls as $yaml) {
@@ -458,7 +458,7 @@ EOF;
 
                 $this->fail('charsets other than UTF-8 are rejected.');
             } catch (\Exception $e) {
-                 $this->assertInstanceOf('Symfony\Component\Yaml\Exception\ParseException', $e, 'charsets other than UTF-8 are rejected.');
+                $this->assertInstanceOf('Symfony\Component\Yaml\Exception\ParseException', $e, 'charsets other than UTF-8 are rejected.');
             }
         }
     }
diff --git a/vendor/symfony/yaml/Symfony/Component/Yaml/Unescaper.php b/vendor/symfony/yaml/Symfony/Component/Yaml/Unescaper.php
index b47d4a59285b92b364074687ad03718717a3ce85..50b1018c404c138bdbbee739259200ad96c154c8 100644
--- a/vendor/symfony/yaml/Symfony/Component/Yaml/Unescaper.php
+++ b/vendor/symfony/yaml/Symfony/Component/Yaml/Unescaper.php
@@ -130,12 +130,12 @@ class Unescaper
             return chr($c);
         }
         if (0x800 > $c) {
-            return chr(0xC0 | $c>>6).chr(0x80 | $c & 0x3F);
+            return chr(0xC0 | $c >> 6).chr(0x80 | $c & 0x3F);
         }
         if (0x10000 > $c) {
-            return chr(0xE0 | $c>>12).chr(0x80 | $c>>6 & 0x3F).chr(0x80 | $c & 0x3F);
+            return chr(0xE0 | $c >> 12).chr(0x80 | $c >> 6 & 0x3F).chr(0x80 | $c & 0x3F);
         }
 
-        return chr(0xF0 | $c>>18).chr(0x80 | $c>>12 & 0x3F).chr(0x80 | $c>>6 & 0x3F).chr(0x80 | $c & 0x3F);
+        return chr(0xF0 | $c >> 18).chr(0x80 | $c >> 12 & 0x3F).chr(0x80 | $c >> 6 & 0x3F).chr(0x80 | $c & 0x3F);
     }
 }
diff --git a/vendor/symfony/yaml/Symfony/Component/Yaml/Inline.php b/vendor/symfony/yaml/Symfony/Component/Yaml/Inline.php
index b029e81377dc6f82dfaf1d62f351f70e14ee0272..8fec216dde139c7bc3caca24ad349339d97d79c8 100644
--- a/vendor/symfony/yaml/Symfony/Component/Yaml/Inline.php
+++ b/vendor/symfony/yaml/Symfony/Component/Yaml/Inline.php
@@ -410,7 +410,7 @@ class Inline
      *
      * @return string A YAML string
      *
      * @throws ParseException when object parsing support was disabled and the parser detected a PHP object
      */
     private static function evaluateScalar($scalar, $references = array())
     {
@@ -424,6 +424,11 @@ class Inline
                 $value = substr($scalar, 1);
             }
 
+            // an unquoted *
+            if (false === $value || '' === $value) {
+                throw new ParseException('A reference must contain at least one character.');
+            }
+
             if (!array_key_exists($value, $references)) {
                 throw new ParseException(sprintf('Reference "%s" does not exist.', $value));
             }
@@ -410,7 +410,7 @@ class Inline
      * @return string A YAML string
      *
-     * @throws ParseException when object parsing support was disabled and the parser detected a PHP object
+     * @throws ParseException when object parsing support was disabled and the parser detected a PHP object or when a reference could not be resolved
      */
     private static function evaluateScalar($scalar, $references = array())
diff --git a/vendor/symfony/yaml/Symfony/Component/Yaml/Parser.php b/vendor/symfony/yaml/Symfony/Component/Yaml/Parser.php
index 2204ffc4f5727e3b72497f42d19f5fe676f41df7..fd9afafe36b4dbdb3edd96423b68dccf8f627fd5 100644
--- a/vendor/symfony/yaml/Symfony/Component/Yaml/Parser.php
+++ b/vendor/symfony/yaml/Symfony/Component/Yaml/Parser.php
@@ -93,8 +93,8 @@ class Parser
                 if (!isset($values['value']) || '' == trim($values['value'], ' ') || 0 === strpos(ltrim($values['value'], ' '), '#')) {
                     $c = $this->getRealCurrentLineNb() + 1;
                     $parser = new Parser($c);
-                    $parser->refs =& $this->refs;
-                    $data[] = $parser->parse($this->getNextEmbedBlock(), $exceptionOnInvalidType, $objectSupport);
+                    $parser->refs = & $this->refs;
+                    $data[] = $parser->parse($this->getNextEmbedBlock(null, true), $exceptionOnInvalidType, $objectSupport);
                 } else {
                     if (isset($values['leadspaces'])
                         && ' ' == $values['leadspaces']
@@ -103,7 +103,7 @@ class Parser
                         // this is a compact notation element, add to next block and parse
                         $c = $this->getRealCurrentLineNb();
                         $parser = new Parser($c);
-                        $parser->refs =& $this->refs;
+                        $parser->refs = & $this->refs;
 
                         $block = $values['value'];
                         if ($this->isNextLineIndented()) {
@@ -160,7 +160,7 @@ class Parser
                         }
                         $c = $this->getRealCurrentLineNb() + 1;
                         $parser = new Parser($c);
-                        $parser->refs =& $this->refs;
+                        $parser->refs = & $this->refs;
                         $parsed = $parser->parse($value, $exceptionOnInvalidType, $objectSupport);
 
                         if (!is_array($parsed)) {
@@ -211,7 +211,7 @@ class Parser
                     } else {
                         $c = $this->getRealCurrentLineNb() + 1;
                         $parser = new Parser($c);
-                        $parser->refs =& $this->refs;
+                        $parser->refs = & $this->refs;
                         $value = $parser->parse($this->getNextEmbedBlock(), $exceptionOnInvalidType, $objectSupport);
                         // Spec: Keys MUST be unique; first one wins.
                         // But overwriting is allowed when a merge node is used in current block.
@@ -316,15 +316,20 @@ class Parser
     /**
      * Returns the next embed block of YAML.
      *
      * @param int     $indentation The indent level at which the block is to be read, or null for default
      *
      * @return string A YAML string
      *
      * @throws ParseException When indentation problem are detected
      */
-    private function getNextEmbedBlock($indentation = null)
+    private function getNextEmbedBlock($indentation = null, $inSequence = false)
     {
-        $this->moveToNextLine();
+        $oldLineIndentation = $this->getCurrentLineIndentation();
+
+        if (!$this->moveToNextLine()) {
+            return;
+        }
 
         if (null === $indentation) {
             $newIndent = $this->getCurrentLineIndentation();
@@ -340,6 +345,14 @@ class Parser
 
         $data = array(substr($this->currentLine, $newIndent));
 
+        if ($inSequence && $oldLineIndentation === $newIndent && '-' === $data[0][0]) {
+            // the previous line contained a dash but no item content, this line is a sequence item with the same indentation
+            // and therefore no nested list or mapping
+            $this->moveToPreviousLine();
+
+            return;
+        }
+
         $isItUnindentedCollection = $this->isStringUnIndentedCollectionItem($this->currentLine);
 
         // Comments must not be removed inside a string block (ie. after a line ending with "|")
@@ -669,5 +682,4 @@ class Parser
     {
         return (0 === strpos($this->currentLine, '- '));
     }
-
 }
@@ -316,15 +316,20 @@ class Parser
      * Returns the next embed block of YAML.
      *
-     * @param int     $indentation The indent level at which the block is to be read, or null for default
+     * @param int  $indentation The indent level at which the block is to be read, or null for default
+     * @param bool $inSequence  True if the enclosing data structure is a sequence
      *
      * @return string A YAML string